@@ -61,7 +61,7 @@ namespace NETGeographicLib
    *
    * The following functions are implemented as properties:
    * Latitude, Longitude, Azimuth, EquatorialAzimuth, EquatorialArc,
-   * MajorRadius, Distance, Arc, and Flattening.
+   * EquatorialRadius, Distance, Arc, and Flattening.
    *
    * The constructors, Capabilities, and GenPosition functions accept the
    * "capabilities mask" as a NETGeographicLib::Mask rather than an
@@ -602,7 +602,7 @@ namespace NETGeographicLib
          * @return \e a the equatorial radius of the ellipsoid (meters).  This is
          *   the value inherited from the Geodesic object used in the constructor.
          **********************************************************************/
-        property double MajorRadius { double get(); }
+        property double EquatorialRadius { double get(); }
 
         /**
          * @return \e f the flattening of the ellipsoid.  This is the value
