@@ -11,7 +11,7 @@ using namespace GeographicLib;
 int main() {
   try {
     NormalGravity grav(Constants::WGS84_a(), Constants::WGS84_GM(),
-                       Constants::WGS84_omega(), Constants::WGS84_f(), 0);
+                       Constants::WGS84_omega(), Constants::WGS84_f());
     // Alternatively: const NormalGravity& grav = NormalGravity::WGS84();
     double lat = 27.99, h = 8820; // Mt Everest
     double gammay, gammaz;
@@ -22,5 +22,4 @@ int main() {
     cerr << "Caught exception: " << e.what() << "\n";
     return 1;
   }
-  return 0;
 }
