@@ -2,7 +2,7 @@
  * \file LambertConformalConic.hpp
  * \brief Header for GeographicLib::LambertConformalConic class
  *
- * Copyright (c) Charles Karney (2010-2019) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2010-2020) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -68,7 +68,10 @@ namespace GeographicLib {
     real _sign, _n, _nc, _t0nm1, _scale, _lat0, _k0;
     real _scbet0, _tchi0, _scchi0, _psi0, _nrho0, _drhomax;
     static const int numit_ = 5;
-    static real hyp(real x) { return Math::hypot(real(1), x); }
+    static real hyp(real x) {
+      using std::hypot;
+      return hypot(real(1), x);
+    }
     // Divided differences
     // Definition: Df(x,y) = (f(x)-f(y))/(x-y)
     // See:
@@ -98,8 +101,9 @@ namespace GeographicLib {
     }
     // Dlog1p(x,y) = log1p((x-y)/(1+y))/(x-y)
     static real Dlog1p(real x, real y) {
+      using std::log1p;
       real t = x - y; if (t < 0) { t = -t; y = x; }
-      return t != 0 ? Math::log1p(t / (1 + y)) / t : 1 / (1 + x);
+      return t != 0 ? log1p(t / (1 + y)) / t : 1 / (1 + x);
     }
     // Dexp(x,y) = exp((x+y)/2) * 2*sinh((x-y)/2)/(x-y)
     static real Dexp(real x, real y) {
@@ -124,9 +128,10 @@ namespace GeographicLib {
     //             = asinh((x*sqrt(1+y^2)-y*sqrt(1+x^2)))/(x-y)
     static real Dasinh(real x, real y, real hx, real hy) {
       // hx = hyp(x)
+      using std::asinh;
       real t = x - y;
       return t != 0 ?
-        Math::asinh(x*y > 0 ? t * (x + y) / (x*hy + y*hx) : x*hy - y*hx) / t :
+        asinh(x*y > 0 ? t * (x + y) / (x*hy + y*hx) : x*hy - y*hx) / t :
         1 / hx;
     }
     // Deatanhe(x,y) = eatanhe((x-y)/(1-e^2*x*y))/(x-y)
@@ -306,9 +311,9 @@ namespace GeographicLib {
     Math::real CentralScale() const { return _k0; }
 
     /**
-      * \deprecated An old name for EquatorialRadius().
-      **********************************************************************/
-    // GEOGRAPHICLIB_DEPRECATED("Use EquatorialRadius()")
+     * \deprecated An old name for EquatorialRadius().
+     **********************************************************************/
+    GEOGRAPHICLIB_DEPRECATED("Use EquatorialRadius()")
     Math::real MajorRadius() const { return EquatorialRadius(); }
     ///@}
 
