@@ -2,7 +2,7 @@
  * \file PolygonArea.hpp
  * \brief Header for GeographicLib::PolygonAreaT class
  *
- * Copyright (c) Charles Karney (2010-2019) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2010-2020) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -96,13 +96,17 @@ namespace GeographicLib {
     static int transitdirect(real lon1, real lon2) {
       // Compute exactly the parity of
       //   int(ceil(lon2 / 360)) - int(ceil(lon1 / 360))
-      lon1 = Math::remainder(lon1, real(720));
-      lon2 = Math::remainder(lon2, real(720));
+      using std::remainder;
+      lon1 = remainder(lon1, real(720));
+      lon2 = remainder(lon2, real(720));
       return ( (lon2 <= 0 && lon2 > -360 ? 1 : 0) -
                (lon1 <= 0 && lon1 > -360 ? 1 : 0) );
     }
     void Remainder(Accumulator<>& a) const { a.remainder(_area0); }
-    void Remainder(real& a) const { a = Math::remainder(a, _area0); }
+    void Remainder(real& a) const {
+      using std::remainder;
+      a = remainder(a, _area0);
+    }
     template <typename T>
     void AreaReduce(T& area, int crossings, bool reverse, bool sign) const;
   public:
@@ -257,9 +261,9 @@ namespace GeographicLib {
     { lat = _lat1; lon = _lon1; }
 
     /**
-      * \deprecated An old name for EquatorialRadius().
-      **********************************************************************/
-    // GEOGRAPHICLIB_DEPRECATED("Use EquatorialRadius()")
+     * \deprecated An old name for EquatorialRadius().
+     **********************************************************************/
+    GEOGRAPHICLIB_DEPRECATED("Use EquatorialRadius()")
     Math::real MajorRadius() const { return EquatorialRadius(); }
     ///@}
   };
