@@ -1,7 +1,7 @@
 /**
  * Implementation of the net.sf.geographiclib.Pair class
  *
- * Copyright (c) Charles Karney (2013) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2013-2020) <charles@karney.com>∑ and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -29,4 +29,8 @@ public class Pair {
    **********************************************************************/
   public Pair(double first, double second)
   { this.first = first; this.second = second; }
+  /**
+   * No-argument Constructor
+   **********************************************************************/
+  public Pair() {}
 }
