@@ -24,7 +24,7 @@ int main() {
   struct geod_geodesic g;
 
   geod_init(&g, a, f);
-  while (scanf("%lf %lf %lf %lf\n", &lat1, &lon1, &lat2, &lon2) == 4) {
+  while (scanf("%lf %lf %lf %lf", &lat1, &lon1, &lat2, &lon2) == 4) {
     geod_inverse(&g, lat1, lon1, lat2, lon2, &s12, &azi1, &azi2);
     printf("%.15f %.15f %.10f\n", azi1, azi2, s12);
   }
