@@ -25,14 +25,14 @@ function [lat, lon, azi, rk] = eqdazim_inv(lat0, lon0, x, y, ellipsoid)
 %
 %   Section 14 of
 %
-%     C. F. F. Karney, Geodesics on an ellipsoid of revolution (2011),
-%     http://arxiv.org/abs/1102.1215
-%     Errata: http://geographiclib.sourceforge.net/geod-addenda.html#geod-errata
+%    C. F. F. Karney, Geodesics on an ellipsoid of revolution (2011),
+%    https://arxiv.org/abs/1102.1215
+%    Errata: https://geographiclib.sourceforge.io/geod-addenda.html#geod-errata
 %
 %   describes how to use this projection in the determination of maritime
 %   boundaries (finding the median line).
 %
-%   See also PROJDOC, EQDAZIM_FWD, GEODRECKON, DEFAULTELLIPSOID.
+%   See also PROJDOC, EQDAZIM_FWD, GEODRECKON, DEFAULTELLIPSOID, FLAT2ECC.
 
 % Copyright (c) Charles Karney (2012-2015) <charles@karney.com>.
 
@@ -46,7 +46,8 @@ function [lat, lon, azi, rk] = eqdazim_inv(lat0, lon0, x, y, ellipsoid)
 
   azi0 = atan2dx(x, y);
   s = hypot(x, y);
-  [lat, lon, azi, ~, m, ~, ~, sig] = geodreckon(lat0, lon0, s, azi0, ellipsoid);
+  [lat, lon, azi, ~, m, ~, ~, sig] = ...
+      geodreckon(lat0, lon0, s, azi0, ellipsoid);
   rk = m ./ s;
   rk(sig <= 0.01 * sqrt(realmin)) = 1;
 end
