@@ -41,7 +41,7 @@ function [s12, azi1, azi2, S12, m12, M12, M21, a12] = geoddistance ...
 %
 %   See also GEODDOC, GEODRECKON, GEODAREA, DEFAULTELLIPSOID, FLAT2ECC.
 
-% Copyright (c) Charles Karney (2012-2017) <charles@karney.com>.
+% Copyright (c) Charles Karney (2012-2019) <charles@karney.com>.
 %
 % This is a straightforward transcription of the C++ implementation in
 % GeographicLib and the C++ source should be consulted for additional
@@ -268,6 +268,8 @@ function [s12, azi1, azi2, S12, m12, M12, M21, a12] = geoddistance ...
     salp0 = salp1 .* cbet1; calp0 = hypot(calp1, salp1 .* sbet1);
     ssig1 = sbet1; csig1 = calp1 .* cbet1;
     ssig2 = sbet2; csig2 = calp2 .* cbet2;
+    % Stop complaints from norm2 for equatorial geodesics
+    csig1(calp0 == 0) = 1; csig2(calp0 == 0) = 1;
     k2 = calp0.^2 * ep2;
     epsi = k2 ./ (2 * (1 + sqrt(1 + k2)) + k2);
     A4 = (a^2 * e2) * calp0 .* salp0;
@@ -458,7 +460,7 @@ function k = Astroid(x, y)
   T3 = S(fl2) + r3(fl2);
   T3 = T3 + (1 - 2 * (T3 < 0)) .* sqrt(disc(fl2));
   T = cbrtx(T3);
-  u(fl2) = u(fl2) + T + cvmgt(r2(fl2) ./ T, 0, T ~= 0);
+  u(fl2) = u(fl2) + T + r2(fl2) ./ cvmgt(T, inf, T ~= 0);
   ang = atan2(sqrt(-disc(~fl2)), -(S(~fl2) + r3(~fl2)));
   u(~fl2) = u(~fl2) + 2 * r(~fl2) .* cos(ang / 3);
   v = sqrt(u.^2 + q);
