@@ -11,8 +11,8 @@ function z = copysignx(x, y)
   if octavep
     z = abs(x) .* (1 - 2 * signbit(y));
   else
-    z = abs(x);
-    l = y < 0 | (y == 0 & 1/y < 0);
+    z = abs(x + 0*y);
+    l = z > -1 & (y < 0 | (y == 0 & 1./y < 0));
     z(l) = -z(l);
   end
 end
