@@ -2,7 +2,7 @@
  * \file Geodesic.cpp
  * \brief Implementation for GeographicLib::Geodesic class
  *
- * Copyright (c) Charles Karney (2009-2019) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2020) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  *
@@ -77,9 +77,9 @@ namespace GeographicLib {
     , _etol2(real(0.1) * tol2_ /
              sqrt( max(real(0.001), abs(_f)) * min(real(1), 1 - _f/2) / 2 ))
   {
-    if (!(Math::isfinite(_a) && _a > 0))
+    if (!(isfinite(_a) && _a > 0))
       throw GeographicErr("Equatorial radius is not positive");
-    if (!(Math::isfinite(_b) && _b > 0))
+    if (!(isfinite(_b) && _b > 0))
       throw GeographicErr("Polar semi-axis is not positive");
     A3coeff();
     C3coeff();
@@ -418,7 +418,7 @@ namespace GeographicLib {
       real
         // From Lambda12: sin(alp1) * cos(bet1) = sin(alp0)
         salp0 = salp1 * cbet1,
-        calp0 = Math::hypot(calp1, salp1 * sbet1); // calp0 > 0
+        calp0 = hypot(calp1, salp1 * sbet1); // calp0 > 0
       real alp12;
       if (calp0 != 0 && salp0 != 0) {
         real
@@ -610,7 +610,7 @@ namespace GeographicLib {
         // of the way the T is used in definition of u.
         T3 += T3 < 0 ? -sqrt(disc) : sqrt(disc); // T3 = (r * t)^3
         // N.B. cbrt always returns the real root.  cbrt(-8) = -2.
-        real T = Math::cbrt(T3); // T = r * t
+        real T = cbrt(T3); // T = r * t
         // T can be zero; but then r2 / T -> 0.
         u += T + (T != 0 ? r2 / T : 0);
       } else {
@@ -676,7 +676,7 @@ namespace GeographicLib {
       sbet12a - cbet2 * sbet1 * Math::sq(somg12) / (1 - comg12);
 
     real
-      ssig12 = Math::hypot(salp1, calp1),
+      ssig12 = hypot(salp1, calp1),
       csig12 = sbet1 * sbet2 + cbet1 * cbet2 * comg12;
 
     if (shortline && ssig12 < _etol2) {
@@ -814,7 +814,7 @@ namespace GeographicLib {
     real
       // sin(alp1) * cos(bet1) = sin(alp0)
       salp0 = salp1 * cbet1,
-      calp0 = Math::hypot(calp1, salp1 * sbet1); // calp0 > 0
+      calp0 = hypot(calp1, salp1 * sbet1); // calp0 > 0
 
     real somg1, comg1, somg2, comg2, somg12, comg12, lam12;
     // tan(bet1) = tan(sig1) * cos(alp1)
@@ -962,8 +962,8 @@ namespace GeographicLib {
 #else
 #error "Bad value for GEOGRAPHICLIB_GEODESIC_ORDER"
 #endif
-    GEOGRAPHICLIB_STATIC_ASSERT(sizeof(coeff) / sizeof(real) == nA1_/2 + 2,
-                                "Coefficient array size mismatch in A1m1f");
+    static_assert(sizeof(coeff) / sizeof(real) == nA1_/2 + 2,
+                  "Coefficient array size mismatch in A1m1f");
     int m = nA1_/2;
     real t = Math::polyval(m, coeff, Math::sq(eps)) / coeff[m + 1];
     return (t + eps) / (1 - eps);
@@ -1059,9 +1059,9 @@ namespace GeographicLib {
 #else
 #error "Bad value for GEOGRAPHICLIB_GEODESIC_ORDER"
 #endif
-    GEOGRAPHICLIB_STATIC_ASSERT(sizeof(coeff) / sizeof(real) ==
-                                (nC1_*nC1_ + 7*nC1_ - 2*(nC1_/2)) / 4,
-                                "Coefficient array size mismatch in C1f");
+    static_assert(sizeof(coeff) / sizeof(real) ==
+                  (nC1_*nC1_ + 7*nC1_ - 2*(nC1_/2)) / 4,
+                  "Coefficient array size mismatch in C1f");
     real
       eps2 = Math::sq(eps),
       d = eps;
@@ -1165,9 +1165,9 @@ namespace GeographicLib {
 #else
 #error "Bad value for GEOGRAPHICLIB_GEODESIC_ORDER"
 #endif
-    GEOGRAPHICLIB_STATIC_ASSERT(sizeof(coeff) / sizeof(real) ==
-                                (nC1p_*nC1p_ + 7*nC1p_ - 2*(nC1p_/2)) / 4,
-                                "Coefficient array size mismatch in C1pf");
+    static_assert(sizeof(coeff) / sizeof(real) ==
+                  (nC1p_*nC1p_ + 7*nC1p_ - 2*(nC1p_/2)) / 4,
+                  "Coefficient array size mismatch in C1pf");
     real
       eps2 = Math::sq(eps),
       d = eps;
@@ -1207,8 +1207,8 @@ namespace GeographicLib {
 #else
 #error "Bad value for GEOGRAPHICLIB_GEODESIC_ORDER"
 #endif
-    GEOGRAPHICLIB_STATIC_ASSERT(sizeof(coeff) / sizeof(real) == nA2_/2 + 2,
-                                "Coefficient array size mismatch in A2m1f");
+    static_assert(sizeof(coeff) / sizeof(real) == nA2_/2 + 2,
+                  "Coefficient array size mismatch in A2m1f");
     int m = nA2_/2;
     real t = Math::polyval(m, coeff, Math::sq(eps)) / coeff[m + 1];
     return (t - eps) / (1 + eps);
@@ -1304,9 +1304,9 @@ namespace GeographicLib {
 #else
 #error "Bad value for GEOGRAPHICLIB_GEODESIC_ORDER"
 #endif
-    GEOGRAPHICLIB_STATIC_ASSERT(sizeof(coeff) / sizeof(real) ==
-                                (nC2_*nC2_ + 7*nC2_ - 2*(nC2_/2)) / 4,
-                                "Coefficient array size mismatch in C2f");
+    static_assert(sizeof(coeff) / sizeof(real) ==
+                  (nC2_*nC2_ + 7*nC2_ - 2*(nC2_/2)) / 4,
+                  "Coefficient array size mismatch in C2f");
     real
       eps2 = Math::sq(eps),
       d = eps;
@@ -1410,9 +1410,9 @@ namespace GeographicLib {
 #else
 #error "Bad value for GEOGRAPHICLIB_GEODESIC_ORDER"
 #endif
-    GEOGRAPHICLIB_STATIC_ASSERT(sizeof(coeff) / sizeof(real) ==
-                                (nA3_*nA3_ + 7*nA3_ - 2*(nA3_/2)) / 4,
-                                "Coefficient array size mismatch in A3f");
+    static_assert(sizeof(coeff) / sizeof(real) ==
+                  (nA3_*nA3_ + 7*nA3_ - 2*(nA3_/2)) / 4,
+                  "Coefficient array size mismatch in A3f");
     int o = 0, k = 0;
     for (int j = nA3_ - 1; j >= 0; --j) { // coeff of eps^j
       int m = min(nA3_ - j - 1, j);       // order of polynomial in n
@@ -1614,9 +1614,9 @@ namespace GeographicLib {
 #else
 #error "Bad value for GEOGRAPHICLIB_GEODESIC_ORDER"
 #endif
-    GEOGRAPHICLIB_STATIC_ASSERT(sizeof(coeff) / sizeof(real) ==
-                                ((nC3_-1)*(nC3_*nC3_ + 7*nC3_ - 2*(nC3_/2)))/8,
-                                "Coefficient array size mismatch in C3coeff");
+    static_assert(sizeof(coeff) / sizeof(real) ==
+                  ((nC3_-1)*(nC3_*nC3_ + 7*nC3_ - 2*(nC3_/2)))/8,
+                  "Coefficient array size mismatch in C3coeff");
     int o = 0, k = 0;
     for (int l = 1; l < nC3_; ++l) {        // l is index of C3[l]
       for (int j = nC3_ - 1; j >= l; --j) { // coeff of eps^j
@@ -1883,9 +1883,9 @@ namespace GeographicLib {
 #else
 #error "Bad value for GEOGRAPHICLIB_GEODESIC_ORDER"
 #endif
-    GEOGRAPHICLIB_STATIC_ASSERT(sizeof(coeff) / sizeof(real) ==
-                                (nC4_ * (nC4_ + 1) * (nC4_ + 5)) / 6,
-                                "Coefficient array size mismatch in C4coeff");
+    static_assert(sizeof(coeff) / sizeof(real) ==
+                  (nC4_ * (nC4_ + 1) * (nC4_ + 5)) / 6,
+                  "Coefficient array size mismatch in C4coeff");
     int o = 0, k = 0;
     for (int l = 0; l < nC4_; ++l) {        // l is index of C4[l]
       for (int j = nC4_ - 1; j >= l; --j) { // coeff of eps^j
