@@ -2,7 +2,7 @@
  * \file Gnomonic.cpp
  * \brief Implementation for GeographicLib::Gnomonic class
  *
- * Copyright (c) Charles Karney (2010-2019) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2010-2020) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -48,7 +48,7 @@ namespace GeographicLib {
                          real& lat, real& lon, real& azi, real& rk) const {
     real
       azi0 = Math::atan2d(x, y),
-      rho = Math::hypot(x, y),
+      rho = hypot(x, y),
       s = _a * atan(rho/_a);
     bool little = rho <= _a;
     if (!little)
